netcup
    * ``auth_customer_id`` Specify customer number for authentication

    * ``auth_api_key`` Specify api key for authentication

    * ``auth_api_password`` Specify api password for authentication
